@@ -36,14 +36,14 @@ class MyPaintWidget(Widget):
             if len(last_stroke) > 0:
                 recording.append(last_stroke)
                 last_stroke = []
-            point = {"x": touch.x, "y": -touch.y, "time": unix_time()}
+            point = {"x": touch.x, "y": touch.y, "time": unix_time()}
             last_stroke.append(point)
 
     def on_touch_move(self, touch):
         global last_stroke
         touch.ud['line'].points += [touch.x, touch.y]
         # Record keeping
-        point = {"x": touch.x, "y": -touch.y, "time": unix_time()}
+        point = {"x": touch.x, "y": touch.y, "time": unix_time()}
         last_stroke.append(point)
 
 
@@ -63,6 +63,9 @@ def get_parser():
                         metavar="FOLDER",
                         type=lambda x: utils.is_valid_folder(parser, x),
                         default=utils.default_model())
+    parser.add_argument("-n",
+                        dest="n", default=10, type=int,
+                        help="Show TOP-N results")
     return parser
 
 
@@ -76,5 +79,10 @@ if __name__ == '__main__':
     logging.info(recording)
     logging.info("Start evaluation...")
     results = utils.classify_single_recording(raw_data_json, args.model)
+    n = args.n
     for latex, probability in results:
+        if n == 0:
+            break
+        else:
+            n -= 1
         print("{0:18s} {1:5f}".format(latex, probability))
